#  tests for preshed-3.0.5-py39h29c3540_2 (this is a generated file);
print('===== testing package: preshed-3.0.5-py39h29c3540_2 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import preshed
import pytest

PACKAGE_DIR = os.path.abspath(os.path.dirname(preshed.__file__))
pytest.main([PACKAGE_DIR])
#  --- run_test.py (end) ---

print('===== preshed-3.0.5-py39h29c3540_2 OK =====');
print("import: 'preshed'")
import preshed

